# passerelle-imio-liege-lisrue - passerelle connector to Lisrue webservice
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import urlparse
import requests

from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _

from passerelle.base.models import BaseResource


class ImioLiegeLisrue(BaseResource):
    service_url = models.CharField(max_length=128, blank=False,
            verbose_name=_('Service URL'),
            help_text=_('SIG Web Service URL (ex: https://e-services.liege.be:8443/)'))
    verify_cert = models.BooleanField(default=True,
            verbose_name=_('Check HTTPS Certificate validity'))

    category = _('Geographic information system')

    class Meta:
        verbose_name = _('Liege Lisrue Service')

    def get_absolute_url(self):
        return reverse('imio-liege-lisrue-view', kwargs={'slug': self.slug})

    def sig_request(self, endpoint, **kwargs):
        if not self.verify_cert:
            kwargs['verify'] = False
        return requests.get(self.service_url + '/adresse/rest/' + endpoint, **kwargs).json()

    @classmethod
    def get_add_url(cls):
        return reverse('imio-liege-lisrue-add')

    @classmethod
    def get_verbose_name(cls):
        return cls._meta.verbose_name

    @classmethod
    def get_icon_class(cls):
        return 'gis'
